@@ -12,8 +12,7 @@
 # language governing permissions and limitations under the License.
 import pytest
 
-from tests import create_session, mock, ClientHTTPStubber
-
+from tests import ClientHTTPStubber, create_session, mock
 
 OPERATION_PARAMS = {
     'change_password': {
